***********************************************************************************
	*******************************Data preparation********************************
	*******************************************************************************

	*********************************From Eurostat*****************************
	clear
	import excel using "Eurostat_Output_Agriculture.xls", sheet("Tab2") firstrow
	forvalues i=1973(1)2015 {
	cap noisily destring i`i',replace
	}
	reshape long i, i(code) j(year)
	ren i Output_agric
	label   var Output_agric    "Production value at basic price Million euro of agricultural industry"
	ren code country_name

	saveold "data processed\Eurostat.dta",replace 
	

	******************************Coded EU Comm Presidents***********************************
	clear
	import excel using "EUcomm_presidents.xlsx", sheet("data") firstrow
	drop H I //empty columns
	encode code, gen(country_num)

	
	gen edate=mdy(month, day, year) // Time var
	label var edate "Date in day, month, year Stata format"
	format edate %dM_d,_CY 
	sort country_num edate, stable
	tsset country_num edate
	quietly tsfill,full

	************fill up president variable*********
	by country_num: carryforward   Eupres,replace
	replace Eupres=0 if Eupres==. //Important so that empty values prior to first EU pres are coded correctly as 0
	gsort + country_num + year
	by country_num: carryforward   code,replace
	gsort + country_num + year
	by country_num: carryforward code  Eupres,replace
	gsort + country_num + edate //Correct coding
	*Generate and extrapolate month and day
	replace month=month(edate)
	replace day=day(edate)
	replace year=year(edate)
	*bys country_num year: egen pres_com=mean(Eupres)

	collapse (first) code   (mean) Eupres, by(country_num year)
	keep code year Eupres
	saveold "data processed\Eupres.dta",replace 


	******************************Coded EU Council Presidencies***********************************
	clear
	import excel using "EUcouncilpres.xlsx", sheet("data") firstrow
	keep code year halfyear
	gen Eucouncil=1
	saveold "data processed\Eucouncil.dta",replace 
		 

	********Update and fill up some variables missing in original data set**************************
	*Data from Worldbank using the wbopendata command. Data saved as of 1st of December 2016. The World
	* Bank changes and updates coding and data several times a year. Comment this part in to get the newest
	* data. Note that this might cause minimal changes in some coefficients in the future.
	/*
	clear
	local NO=1
	foreach var in AG.AGR.TRAC.NO    AG.LND.AGRI.K2    AG.LND.AGRI.ZS AG.LND.IRIG.AG.ZS    EA.PRD.AGRI.KD    NV.AGR.TOTL.KD  SL.UEM.TOTL.FE.ZS SL.UEM.TOTL.MA.ZS ///
	NV.AGR.TOTL.ZS    SL.AGR.EMPL.ZS NV.AGR.TOTL.ZS SL.TLF.TOTL.IN SL.UEM.TOTL.ZS SL.AGR.EMPL.ZS SL.TLF.TOTL.FE.ZS SL.AGR.EMPL.FE.ZS SL.AGR.EMPL.MA.ZS {
	quietly wbopendata, language(en - English) country(ALL) topics() indicator(`var') clear long nometadata	/*GDP- Current US Dollar*/
	keep if regioncode=="ECS" | regioncode=="NA" | regioncode=="" /* drops non-countries */
		drop iso2code region regioncode
		ren countryname country_name
		save "data processed\WDI`NO'",replace
		local NO=`NO'+1
	}

	use "data processed\WDI1.dta",clear
	forvalue i=2(1)17 {
	merge 1:1  country_name year using  "data processed\WDI`i'", nogen
	}

	label	variable	ag_agr_trac_no	"	Agricultural irrigated land (% of total agricultural land)	"
	label	variable	ag_lnd_agri_k2	"	Agricultural land (% of land area)	"
	label	variable	ag_lnd_agri_zs	"	Agricultural land (sq. km)	"
	label	variable	ag_lnd_irig_ag_zs	"	Agricultural machinery, tractors	"
	label	variable	ea_prd_agri_kd	"	Agriculture value added per worker (constant 2005 US$)	"
	label	variable	nv_agr_totl_kd	"	Agriculture, value added (constant 2005 US$)"	
	label	variable	nv_agr_totl_zs	"    Agriculture, value added (% of GDP)	"
	label	variable	sl_agr_empl_zs	"	Employment in agriculture (% of total employment)	"
	label variable sl_agr_empl_fe_zs 	"Employees, agriculture, female (% of female employment)"
	label variable sl_agr_empl_ma_zs 	 "Employees, agriculture, male (% of male employment)"
	label variable sl_tlf_totl_fe_zs 	"Labor force, female (% of total labor force)"
	label variable sl_tlf_totl_in 	"Labor force, total"
	label variable sl_uem_totl_fe_zs	 "Unemployment, female (% of female labor force)"
	label variable sl_uem_totl_ma_zs 	"Unemployment, male (% of male labor force)"
	*label var sl_uem_totl_zs 
	
	
	
	*******Labor force male*********
	gen sl_tlf_totl_ma_zs=100-sl_tlf_totl_fe_zs
	label variable sl_tlf_totl_ma_zs "Labor force, male (% of total labor force)"
	
	gen sl_tlf_totl_fe=sl_tlf_totl_in *sl_tlf_totl_fe_zs/100
	label variable sl_tlf_totl_fe 	"Labor force, female"
	gen sl_tlf_totl_ma= sl_tlf_totl_in *sl_tlf_totl_ma_zs/100
	label variable sl_tlf_totl_ma 	"Labor force, male"
		
	*Fill up unemployment
	gen employment_male=sl_tlf_totl_ma*(100- sl_uem_totl_ma_zs)/100
	label variable employment_male 	"total employment, male"
	gen employment_female=sl_tlf_totl_fe*(100- sl_uem_totl_fe_zs)/100
	label variable employment_female 	"total employment, female"
	*Total employment
	gen Total_employ= employment_male + employment_female
	label var Total_employ "Total employment male and female"
	
	**Employment in agriculture
	gen employagri_LOG10=log10(Total_employ*sl_agr_empl_zs/100)
	label var employagri "LOG10_Employment in Agriculture, total"
	
	sort country_name year
	drop if year <1977 |year>2007
	ren countrycode code
	replace country_name="Slovakia" if country_name=="Slovak Republic"
	saveold "data processed\worldindicators.dta",replace 
	*/
	

***************************************************************************************************

	use13   "public_eupower.dta", clear
	ren ifs code
	gen natcom = 0

	//Finn Olav Gundelach 	DAN		6 JAN 77-13 JAN 81 Denmark 
	//Poul Dalsager 		DAN		20 JAN 1981- Jan 85 Denmark 
	//Frans Andriessen 		NED 	7 JAN 1985-5 JAN 89
	//Ray MacSharry 		IRE 	6 Jan 1989- 5 Jan 1993
	//Rene Steichen 		LUX 	6 JAN 1993- 24 JAN 1995
	//Franz Fischler 		AUT 	25 JAN 1995  21 NOV 2004 
	//Sandra Kalniete		LAT 	1 Mai 2004  21 NOV 2004 
	//Mariann Fischer Boel 	DAN 	22 NOV 2004- 9 FEB 2009
	

	replace	natcom	=	1	if	country_name	==	"Denmark"	&	year	==	1977
	replace	natcom	=	1	if	country_name	==	"Denmark"	&	year	==	1978
	replace	natcom	=	1	if	country_name	==	"Denmark"	&	year	==	1979
	replace	natcom	=	1	if	country_name	==	"Denmark"	&	year	==	1980
	replace	natcom	=	1	if	country_name	==	"Denmark"	&	year	==	1981
	replace	natcom	=	1	if	country_name	==	"Denmark"	&	year	==	1982
	replace	natcom	=	1	if	country_name	==	"Denmark"	&	year	==	1983
	replace	natcom	=	1	if	country_name	==	"Denmark"	&	year	==	1984
	replace	natcom	=	0.0833333	if	country_name	==	"Denmark"	&	year	==	2004
	replace	natcom	=	1	if	country_name	==	"Denmark"	&	year	==	2005
	replace	natcom	=	1	if	country_name	==	"Denmark"	&	year	==	2006
	replace	natcom	=	1	if	country_name	==	"Denmark"	&	year	==	2007
	replace	natcom	=	1	if	country_name	==	"Ireland"	&	year	==	1989
	replace	natcom	=	1	if	country_name	==	"Ireland"	&	year	==	1990
	replace	natcom	=	1	if	country_name	==	"Ireland"	&	year	==	1991
	replace	natcom	=	1	if	country_name	==	"Ireland"	&	year	==	1992
	replace	natcom	=	1	if	country_name	==	"Luxembourg"	&	year	==	1993
	replace	natcom	=	1	if	country_name	==	"Luxembourg"	&	year	==	1994
	replace	natcom	=	0.0833333	if	country_name	==	"Luxembourg"	&	year	==	1995
	replace	natcom	=	1	if	country_name	==	"Netherlands"	&	year	==	1985
	replace	natcom	=	1	if	country_name	==	"Netherlands"	&	year	==	1986
	replace	natcom	=	1	if	country_name	==	"Netherlands"	&	year	==	1987
	replace	natcom	=	1	if	country_name	==	"Netherlands"	&	year	==	1988
	replace	natcom	=	0.9166667	if	country_name	==	"Austria"	&	year	==	1995
	replace	natcom	=	1	if	country_name	==	"Austria"	&	year	==	1996
	replace	natcom	=	1	if	country_name	==	"Austria"	&	year	==	1997
	replace	natcom	=	1	if	country_name	==	"Austria"	&	year	==	1998
	replace	natcom	=	1	if	country_name	==	"Austria"	&	year	==	1999
	replace	natcom	=	1	if	country_name	==	"Austria"	&	year	==	2000
	replace	natcom	=	1	if	country_name	==	"Austria"	&	year	==	2001
	replace	natcom	=	1	if	country_name	==	"Austria"	&	year	==	2002
	replace	natcom	=	1	if	country_name	==	"Austria"	&	year	==	2003
	replace	natcom	=	0.9166667	if	country_name	==	"Austria"	&	year	==	2004
	replace	natcom	=	0.5833333	if	country_name	==	"Latvia"	&	year	==	2004

	*Dummy
	gen natcom_puredummy = 0

	replace	natcom_puredummy	=	1	if	country_name	==	"Denmark"	&	year	==	1977
	replace	natcom_puredummy	=	1	if	country_name	==	"Denmark"	&	year	==	1978
	replace	natcom_puredummy	=	1	if	country_name	==	"Denmark"	&	year	==	1979
	replace	natcom_puredummy	=	1	if	country_name	==	"Denmark"	&	year	==	1980
	replace	natcom_puredummy	=	1	if	country_name	==	"Denmark"	&	year	==	1981
	replace	natcom_puredummy	=	1	if	country_name	==	"Denmark"	&	year	==	1982
	replace	natcom_puredummy	=	1	if	country_name	==	"Denmark"	&	year	==	1983
	replace	natcom_puredummy	=	1	if	country_name	==	"Denmark"	&	year	==	1984
	replace	natcom_puredummy	=	1	if	country_name	==	"Denmark"	&	year	==	2004
	replace	natcom_puredummy	=	1	if	country_name	==	"Denmark"	&	year	==	2005
	replace	natcom_puredummy	=	1	if	country_name	==	"Denmark"	&	year	==	2006
	replace	natcom_puredummy	=	1	if	country_name	==	"Denmark"	&	year	==	2007
	replace	natcom_puredummy	=	1	if	country_name	==	"Ireland"	&	year	==	1989
	replace	natcom_puredummy	=	1	if	country_name	==	"Ireland"	&	year	==	1990
	replace	natcom_puredummy	=	1	if	country_name	==	"Ireland"	&	year	==	1991
	replace	natcom_puredummy	=	1	if	country_name	==	"Ireland"	&	year	==	1992
	replace	natcom_puredummy	=	1	if	country_name	==	"Luxembourg"	&	year	==	1993
	replace	natcom_puredummy	=	1	if	country_name	==	"Luxembourg"	&	year	==	1994
	replace	natcom_puredummy	=	1	if	country_name	==	"Luxembourg"	&	year	==	1995
	replace	natcom_puredummy	=	1	if	country_name	==	"Netherlands"	&	year	==	1985
	replace	natcom_puredummy	=	1	if	country_name	==	"Netherlands"	&	year	==	1986
	replace	natcom_puredummy	=	1	if	country_name	==	"Netherlands"	&	year	==	1987
	replace	natcom_puredummy	=	1	if	country_name	==	"Netherlands"	&	year	==	1988
	replace	natcom_puredummy	=	1	if	country_name	==	"Austria"	&	year	==	1995
	replace	natcom_puredummy	=	1	if	country_name	==	"Austria"	&	year	==	1996
	replace	natcom_puredummy	=	1	if	country_name	==	"Austria"	&	year	==	1997
	replace	natcom_puredummy	=	1	if	country_name	==	"Austria"	&	year	==	1998
	replace	natcom_puredummy	=	1	if	country_name	==	"Austria"	&	year	==	1999
	replace	natcom_puredummy	=	1	if	country_name	==	"Austria"	&	year	==	2000
	replace	natcom_puredummy	=	1	if	country_name	==	"Austria"	&	year	==	2001
	replace	natcom_puredummy	=	1	if	country_name	==	"Austria"	&	year	==	2002
	replace	natcom_puredummy	=	1	if	country_name	==	"Austria"	&	year	==	2003
	replace	natcom_puredummy	=	1	if	country_name	==	"Austria"	&	year	==	2004
	replace	natcom_puredummy	=	1	if	country_name	==	"Latvia"	&	year	==	2004



	*******************************************************************************
	**********************Budget Comissioner***************************************
	*******************************************************************************

	gen natcombud = 0

	//Christopher Tugendhat		UK		6 January 1977- 6 January 1985
	//Henning Christophersen    DAN		7 January 1985- 5 January 1989
	//Peter Schmidhuber    		GER		6 January 1989  24 January 1995
	//Erkki Liikanen 			FIN		25 January 1995  17 September 1999
	//Michaele Schreyer 		GER		17 September 1999  22 November 2004
	//Marcos Kyprianou 			CYP		1 May 2004  22 November 2004
	//Dalia Grybauskaite 		LIT		22 November 2004  1 July 2009
	

	replace	natcombud	=	1	if	country_name	==	"United Kingdom"	&	year	==	1977
	replace	natcombud	=	1	if	country_name	==	"United Kingdom"	&	year	==	1978
	replace	natcombud	=	1	if	country_name	==	"United Kingdom"	&	year	==	1979
	replace	natcombud	=	1	if	country_name	==	"United Kingdom"	&	year	==	1980
	replace	natcombud	=	1	if	country_name	==	"United Kingdom"	&	year	==	1981
	replace	natcombud	=	1	if	country_name	==	"United Kingdom"	&	year	==	1982
	replace	natcombud	=	1	if	country_name	==	"United Kingdom"	&	year	==	1983
	replace	natcombud	=	1	if	country_name	==	"United Kingdom"	&	year	==	1984
	replace	natcombud	=	1	if	country_name	==	"Denmark"	&	year	==	1985
	replace	natcombud	=	1	if	country_name	==	"Denmark"	&	year	==	1986
	replace	natcombud	=	1	if	country_name	==	"Denmark"	&	year	==	1987
	replace	natcombud	=	1	if	country_name	==	"Denmark"	&	year	==	1988
	replace	natcombud	=	1	if	country_name	==	"Germany"	&	year	==	1989
	replace	natcombud	=	1	if	country_name	==	"Germany"	&	year	==	1990
	replace	natcombud	=	1	if	country_name	==	"Germany"	&	year	==	1991
	replace	natcombud	=	1	if	country_name	==	"Germany"	&	year	==	1992
	replace	natcombud	=	1	if	country_name	==	"Germany"	&	year	==	1993
	replace	natcombud	=	1	if	country_name	==	"Germany"	&	year	==	1994
	replace	natcombud	=	0.083333333	if	country_name	==	"Germany"	&	year	==	1995
	replace	natcombud	=	0.9166667	if	country_name	==	"Finland"	&	year	==	1996
	replace	natcombud	=	1	if	country_name	==	"Finland"	&	year	==	1997
	replace	natcombud	=	1	if	country_name	==	"Finland"	&	year	==	1998
	replace	natcombud	=	0.75	if	country_name	==	"Finland"	&	year	==	1999
	replace	natcombud	=	0.25	if	country_name	==	"Germany"	&	year	==	1999
	replace	natcombud	=	1	if	country_name	==	"Germany"	&	year	==	2000
	replace	natcombud	=	1	if	country_name	==	"Germany"	&	year	==	2001
	replace	natcombud	=	1	if	country_name	==	"Germany"	&	year	==	2002
	replace	natcombud	=	1	if	country_name	==	"Germany"	&	year	==	2003
	replace	natcombud	=	0.916666667	if	country_name	==	"Germany"	&	year	==	2004
	replace	natcombud	=	0.583333333	if	country_name	==	"Cyprus"	&	year	==	2004
	replace	natcombud	=	0.083333333	if	country_name	==	"Lithunia"	&	year	==	2004
	replace	natcombud	=	1	if	country_name	==	"Lithunia"	&	year	==	2005
	replace	natcombud	=	1	if	country_name	==	"Lithunia"	&	year	==	2006
	replace	natcombud	=	1	if	country_name	==	"Lithunia"	&	year	==	2007

	*Dummy
	gen natcombud_puredummy = 0

	replace	natcombud_puredummy	=	1	if	country_name	==	"United Kingdom"	&	year	==	1977
	replace	natcombud_puredummy	=	1	if	country_name	==	"United Kingdom"	&	year	==	1978
	replace	natcombud_puredummy	=	1	if	country_name	==	"United Kingdom"	&	year	==	1979
	replace	natcombud_puredummy	=	1	if	country_name	==	"United Kingdom"	&	year	==	1980
	replace	natcombud_puredummy	=	1	if	country_name	==	"United Kingdom"	&	year	==	1981
	replace	natcombud_puredummy	=	1	if	country_name	==	"United Kingdom"	&	year	==	1982
	replace	natcombud_puredummy	=	1	if	country_name	==	"United Kingdom"	&	year	==	1983
	replace	natcombud_puredummy	=	1	if	country_name	==	"United Kingdom"	&	year	==	1984
	replace	natcombud_puredummy	=	1	if	country_name	==	"Denmark"	&	year	==	1985
	replace	natcombud_puredummy	=	1	if	country_name	==	"Denmark"	&	year	==	1986
	replace	natcombud_puredummy	=	1	if	country_name	==	"Denmark"	&	year	==	1987
	replace	natcombud_puredummy	=	1	if	country_name	==	"Denmark"	&	year	==	1988
	replace	natcombud_puredummy	=	1	if	country_name	==	"Germany"	&	year	==	1989
	replace	natcombud_puredummy	=	1	if	country_name	==	"Germany"	&	year	==	1990
	replace	natcombud_puredummy	=	1	if	country_name	==	"Germany"	&	year	==	1991
	replace	natcombud_puredummy	=	1	if	country_name	==	"Germany"	&	year	==	1992
	replace	natcombud_puredummy	=	1	if	country_name	==	"Germany"	&	year	==	1993
	replace	natcombud_puredummy	=	1	if	country_name	==	"Germany"	&	year	==	1994
	replace	natcombud_puredummy	=	1	if	country_name	==	"Germany"	&	year	==	1995
	replace	natcombud_puredummy	=	1	if	country_name	==	"Finland"	&	year	==	1996
	replace	natcombud_puredummy	=	1	if	country_name	==	"Finland"	&	year	==	1997
	replace	natcombud_puredummy	=	1	if	country_name	==	"Finland"	&	year	==	1998
	replace	natcombud_puredummy	=	1	if	country_name	==	"Finland"	&	year	==	1999
	replace	natcombud_puredummy	=	1	if	country_name	==	"Germany"	&	year	==	1999
	replace	natcombud_puredummy	=	1	if	country_name	==	"Germany"	&	year	==	2000
	replace	natcombud_puredummy	=	1	if	country_name	==	"Germany"	&	year	==	2001
	replace	natcombud_puredummy	=	1	if	country_name	==	"Germany"	&	year	==	2002
	replace	natcombud_puredummy	=	1	if	country_name	==	"Germany"	&	year	==	2003
	replace	natcombud_puredummy	=	1	if	country_name	==	"Germany"	&	year	==	2004
	replace	natcombud_puredummy	=	1	if	country_name	==	"Cyprus"	&	year	==	2004
	replace	natcombud_puredummy	=	1	if	country_name	==	"Lithunia"	&	year	==	2004
	replace	natcombud_puredummy	=	1	if	country_name	==	"Lithunia"	&	year	==	2005
	replace	natcombud_puredummy	=	1	if	country_name	==	"Lithunia"	&	year	==	2006
	replace	natcombud_puredummy	=	1	if	country_name	==	"Lithunia"	&	year	==	2007


	*******************************************************************************
	**********************Time Trends Comissioner***************************************
	*******************************************************************************

	gen lin_timetrend = 0

	replace	lin_timetrend	=	1	if	year	==	1977
	replace	lin_timetrend	=	2	if	year	==	1978
	replace	lin_timetrend	=	3	if	year	==	1979
	replace	lin_timetrend	=	4	if	year	==	1980
	replace	lin_timetrend	=	5	if	year	==	1981
	replace	lin_timetrend	=	6	if	year	==	1982
	replace	lin_timetrend	=	7	if	year	==	1983
	replace	lin_timetrend	=	8	if	year	==	1984
	replace	lin_timetrend	=	9	if	year	==	1985
	replace	lin_timetrend	=	10	if	year	==	1986
	replace	lin_timetrend	=	11	if	year	==	1987
	replace	lin_timetrend	=	12	if	year	==	1988
	replace	lin_timetrend	=	13	if	year	==	1989
	replace	lin_timetrend	=	14	if	year	==	1990
	replace	lin_timetrend	=	15	if	year	==	1991
	replace	lin_timetrend	=	16	if	year	==	1992
	replace	lin_timetrend	=	17	if	year	==	1993
	replace	lin_timetrend	=	18	if	year	==	1994
	replace	lin_timetrend	=	19	if	year	==	1995
	replace	lin_timetrend	=	20	if	year	==	1996
	replace	lin_timetrend	=	21	if	year	==	1997
	replace	lin_timetrend	=	22	if	year	==	1998
	replace	lin_timetrend	=	23	if	year	==	1999
	replace	lin_timetrend	=	24	if	year	==	2000
	replace	lin_timetrend	=	25	if	year	==	2001
	replace	lin_timetrend	=	26	if	year	==	2002
	replace	lin_timetrend	=	27	if	year	==	2003
	replace	lin_timetrend	=	28	if	year	==	2004
	replace	lin_timetrend	=	29	if	year	==	2005
	replace	lin_timetrend	=	30	if	year	==	2006
	replace	lin_timetrend	=	31	if	year	==	2007

	*Quartic Time Trends
	gen squared_timetrend = lin_timetrend*lin_timetrend
	gen cubic_timetrend = lin_timetrend*lin_timetrend*lin_timetrend
	gen quartic_timetrend = squared_timetrend*squared_timetrend

	*************************************************************
	***************Linear Time Trend for each country************
	*************************************************************

	 forvalues i = 2(1)22 {
	 gen ttrend`i'=id_`i'*lin_timetrend
	}
	 forvalues i = 25(1)27 {
	 gen ttrend`i'=id_`i'*lin_timetrend
	}

	  gen ttrend1=0
	 replace ttrend1=  lin_timetrend if country_id==1 //Belgium

	 
	*Quadratic Time Trend 
	  forvalues i = 2(1)22 {
	 gen squared_ttrend`i'=id_`i'*squared_timetrend
	}
	 forvalues i = 25(1)27 {
	 gen squared_ttrend`i'=id_`i'*squared_timetrend
	}

	  gen squared_ttrend1=0
	 replace squared_ttrend1=  squared_timetrend if country_id==1 //Belgium
	 
	 
	 *Cubic Time Trend 
	  forvalues i = 2(1)22 {
	 gen cubic_ttrend`i'=id_`i'*cubic_timetrend
	}
	 forvalues i = 25(1)27 {
	 gen cubic_ttrend`i'=id_`i'*cubic_timetrend
	}

	  gen cubic_ttrend1=0
	 replace cubic_ttrend1=  cubic_timetrend if country_id==1 //Belgium
	 
	 
	 
	 
	 *This is used in Table 8 Robustness
	  *cubic country specific ttrend
	 forvalues i=1(1)22 {
	 gen t2trend`i'=(ttrend`i')*(ttrend`i')
	 gen t3trend`i'=(ttrend`i')*(ttrend`i')*(ttrend`i')
	  gen t4trend`i'=(ttrend`i')*(ttrend`i')*(ttrend`i')*(ttrend`i')
	 }
	 *cubic country specific ttrend
	 forvalues i=25(1)27 {
	 gen t2trend`i'=(ttrend`i')*(ttrend`i')
	 gen t3trend`i'=(ttrend`i')*(ttrend`i')*(ttrend`i')
	 gen t4trend`i'=(ttrend`i')*(ttrend`i')*(ttrend`i')*(ttrend`i')
	 }
	 
	 
	*************************************************************
	***************Network of EU Commisioner*********************
	*************************************************************
	//Finn Olav Gundelach 	DAN		6 JAN 77-13 JAN 81 Denmark 
	//Poul Dalsager 		DAN		20 JAN 1981- Jan 85 Denmark 
	//Frans Andriessen 		NED 	7 JAN 1985-5 JAN 89
	//Ray MacSharry 		IRE 	6 Jan 1989- 5 Jan 1993
	//Rene Steichen 		LUX 	6 JAN 1993- 24 JAN 1995
	//Franz Fischler 		AUT 	25 JAN 1995  21 NOV 2004 
	//Sandra Kalniete		LAT 	1 Mai 2004  21 NOV 2004 
	//Mariann Fischer Boel 	DAN 	22 NOV 2004- 9 FEB 2009

	gen network = 0

	replace	network	=	1	if	country_name	==	"Denmark"	&	year	==	1977
	replace	network	=	2	if	country_name	==	"Denmark"	&	year	==	1978
	replace	network	=	3	if	country_name	==	"Denmark"	&	year	==	1979
	replace	network	=	4	if	country_name	==	"Denmark"	&	year	==	1980
	replace	network	=	0.9166667	if	country_name	==	"Denmark"	&	year	==	1981
	replace	network	=	1.9166667	if	country_name	==	"Denmark"	&	year	==	1982
	replace	network	=	2.9166667	if	country_name	==	"Denmark"	&	year	==	1983
	replace	network	=	3.9166667	if	country_name	==	"Denmark"	&	year	==	1984
	replace	network	=	0.0833333	if	country_name	==	"Denmark"	&	year	==	2004
	replace	network	=	1.0833333	if	country_name	==	"Denmark"	&	year	==	2005
	replace	network	=	2.0833333	if	country_name	==	"Denmark"	&	year	==	2006
	replace	network	=	3.0833333	if	country_name	==	"Denmark"	&	year	==	2007
	replace	network	=	1	if	country_name	==	"Ireland"	&	year	==	1989
	replace	network	=	2	if	country_name	==	"Ireland"	&	year	==	1990
	replace	network	=	3	if	country_name	==	"Ireland"	&	year	==	1991
	replace	network	=	4	if	country_name	==	"Ireland"	&	year	==	1992
	replace	network	=	1	if	country_name	==	"Luxembourg"	&	year	==	1993
	replace	network	=	2	if	country_name	==	"Luxembourg"	&	year	==	1994
	replace	network	=	2.0833333	if	country_name	==	"Luxembourg"	&	year	==	1995
	replace	network	=	1	if	country_name	==	"Netherlands"	&	year	==	1985
	replace	network	=	2	if	country_name	==	"Netherlands"	&	year	==	1986
	replace	network	=	3	if	country_name	==	"Netherlands"	&	year	==	1987
	replace	network	=	4	if	country_name	==	"Netherlands"	&	year	==	1988
	replace	network	=	0.9166667	if	country_name	==	"Austria"	&	year	==	1995
	replace	network	=	1.9166667	if	country_name	==	"Austria"	&	year	==	1996
	replace	network	=	2.9166667	if	country_name	==	"Austria"	&	year	==	1997
	replace	network	=	3.9166667	if	country_name	==	"Austria"	&	year	==	1998
	replace	network	=	4.9166667	if	country_name	==	"Austria"	&	year	==	1999
	replace	network	=	5.9166667	if	country_name	==	"Austria"	&	year	==	2000
	replace	network	=	6.9166667	if	country_name	==	"Austria"	&	year	==	2001
	replace	network	=	7.9166667	if	country_name	==	"Austria"	&	year	==	2002
	replace	network	=	8.9166667	if	country_name	==	"Austria"	&	year	==	2003
	replace	network	=	9.8333334   if	country_name	==	"Austria"	&	year	==	2004
	replace	network	=	0.5833333	if	country_name	==	"Latvia"	&	year	==	2004

	***Why stop in 2004?
	************************Dummy********************************
	gen network_puredummy = 0

	replace	network_puredummy	=	1	if	country_name	==	"Denmark"	&	year	==	1977
	replace	network_puredummy	=	2	if	country_name	==	"Denmark"	&	year	==	1978
	replace	network_puredummy	=	3	if	country_name	==	"Denmark"	&	year	==	1979
	replace	network_puredummy	=	4	if	country_name	==	"Denmark"	&	year	==	1980
	replace	network_puredummy	=	1	if	country_name	==	"Denmark"	&	year	==	1981
	replace	network_puredummy	=	2	if	country_name	==	"Denmark"	&	year	==	1982
	replace	network_puredummy	=	3	if	country_name	==	"Denmark"	&	year	==	1983
	replace	network_puredummy	=	4	if	country_name	==	"Denmark"	&	year	==	1984
	replace	network_puredummy	=	1	if	country_name	==	"Denmark"	&	year	==	2004
	replace	network_puredummy	=	2	if	country_name	==	"Denmark"	&	year	==	2005
	replace	network_puredummy	=	3	if	country_name	==	"Denmark"	&	year	==	2006
	replace	network_puredummy	=	4	if	country_name	==	"Denmark"	&	year	==	2007
	replace	network_puredummy	=	1	if	country_name	==	"Ireland"	&	year	==	1989
	replace	network_puredummy	=	2	if	country_name	==	"Ireland"	&	year	==	1990
	replace	network_puredummy	=	3	if	country_name	==	"Ireland"	&	year	==	1991
	replace	network_puredummy	=	4	if	country_name	==	"Ireland"	&	year	==	1992
	replace	network_puredummy	=	1	if	country_name	==	"Luxembourg"	&	year	==	1993
	replace	network_puredummy	=	2	if	country_name	==	"Luxembourg"	&	year	==	1994
	replace	network_puredummy	=	3	if	country_name	==	"Luxembourg"	&	year	==	1995
	replace	network_puredummy	=	1	if	country_name	==	"Netherlands"	&	year	==	1985
	replace	network_puredummy	=	2	if	country_name	==	"Netherlands"	&	year	==	1986
	replace	network_puredummy	=	3	if	country_name	==	"Netherlands"	&	year	==	1987
	replace	network_puredummy	=	4	if	country_name	==	"Netherlands"	&	year	==	1988
	replace	network_puredummy	=	1	if	country_name	==	"Austria"	&	year	==	1995
	replace	network_puredummy	=	2	if	country_name	==	"Austria"	&	year	==	1996
	replace	network_puredummy	=	3	if	country_name	==	"Austria"	&	year	==	1997
	replace	network_puredummy	=	4	if	country_name	==	"Austria"	&	year	==	1998
	replace	network_puredummy	=	5	if	country_name	==	"Austria"	&	year	==	1999
	replace	network_puredummy	=	6	if	country_name	==	"Austria"	&	year	==	2000
	replace	network_puredummy	=	7	if	country_name	==	"Austria"	&	year	==	2001
	replace	network_puredummy	=	8	if	country_name	==	"Austria"	&	year	==	2002
	replace	network_puredummy	=	9	if	country_name	==	"Austria"	&	year	==	2003
	replace	network_puredummy	=	10	if	country_name	==	"Austria"	&	year	==	2004
	replace	network_puredummy	=	1	if	country_name	==	"Latvia"	&	year	==	2004

	gen networkbud = 0

	replace	networkbud	=	1	if	country_name	==	"United Kingdom"	&	year	==	1977
	replace	networkbud	=	2	if	country_name	==	"United Kingdom"	&	year	==	1978
	replace	networkbud	=	3	if	country_name	==	"United Kingdom"	&	year	==	1979
	replace	networkbud	=	4	if	country_name	==	"United Kingdom"	&	year	==	1980
	replace	networkbud	=	5	if	country_name	==	"United Kingdom"	&	year	==	1981
	replace	networkbud	=	6	if	country_name	==	"United Kingdom"	&	year	==	1982
	replace	networkbud	=	7	if	country_name	==	"United Kingdom"	&	year	==	1983
	replace	networkbud	=	8	if	country_name	==	"United Kingdom"	&	year	==	1984
	replace	networkbud	=	1	if	country_name	==	"Denmark"	&	year	==	1985
	replace	networkbud	=	2	if	country_name	==	"Denmark"	&	year	==	1986
	replace	networkbud	=	3	if	country_name	==	"Denmark"	&	year	==	1987
	replace	networkbud	=	4	if	country_name	==	"Denmark"	&	year	==	1988
	replace	networkbud	=	1	if	country_name	==	"Germany"	&	year	==	1989
	replace	networkbud	=	2	if	country_name	==	"Germany"	&	year	==	1990
	replace	networkbud	=	3	if	country_name	==	"Germany"	&	year	==	1991
	replace	networkbud	=	4	if	country_name	==	"Germany"	&	year	==	1992
	replace	networkbud	=	5	if	country_name	==	"Germany"	&	year	==	1993
	replace	networkbud	=	6	if	country_name	==	"Germany"	&	year	==	1994
	replace	networkbud	=	6.083333333	if	country_name	==	"Germany"	&	year	==	1995
	replace	networkbud	=	0.9166667	if	country_name	==	"Finland"	&	year	==	1996
	replace	networkbud	=	1.9166667	if	country_name	==	"Finland"	&	year	==	1997
	replace	networkbud	=	2.9166667	if	country_name	==	"Finland"	&	year	==	1998
	replace	networkbud	=	3.6666667	if	country_name	==	"Finland"	&	year	==	1999
	replace	networkbud	=	0.25	if	country_name	==	"Germany"	&	year	==	1999
	replace	networkbud	=	1.25	if	country_name	==	"Germany"	&	year	==	2000
	replace	networkbud	=	2.25	if	country_name	==	"Germany"	&	year	==	2001
	replace	networkbud	=	3.25	if	country_name	==	"Germany"	&	year	==	2002
	replace	networkbud	=	4.25	if	country_name	==	"Germany"	&	year	==	2003
	replace	networkbud	=	5.166666667	if	country_name	==	"Germany"	&	year	==	2004
	replace	networkbud	=	0.583333333	if	country_name	==	"Cyprus"	&	year	==	2004
	replace	networkbud	=	0.083333333	if	country_name	==	"Lithunia"	&	year	==	2004
	replace	networkbud	=	1.083333333	if	country_name	==	"Lithunia"	&	year	==	2005
	replace	networkbud	=	2.083333333	if	country_name	==	"Lithunia"	&	year	==	2006
	replace	networkbud	=	3.083333333	if	country_name	==	"Lithunia"	&	year	==	2007


	gen networkbud_puredummy = 0

	replace	networkbud_puredummy	=	1	if	country_name	==	"United Kingdom"	&	year	==	1977
	replace	networkbud_puredummy	=	2	if	country_name	==	"United Kingdom"	&	year	==	1978
	replace	networkbud_puredummy	=	3	if	country_name	==	"United Kingdom"	&	year	==	1979
	replace	networkbud_puredummy	=	4	if	country_name	==	"United Kingdom"	&	year	==	1980
	replace	networkbud_puredummy	=	5	if	country_name	==	"United Kingdom"	&	year	==	1981
	replace	networkbud_puredummy	=	6	if	country_name	==	"United Kingdom"	&	year	==	1982
	replace	networkbud_puredummy	=	7	if	country_name	==	"United Kingdom"    &	year	==	1983
	replace	networkbud_puredummy	=	8	if	country_name	==	"United Kingdom"	&	year	==	1984
	replace	networkbud_puredummy	=	1	if	country_name	==	"Denmark"	&	year	==	1985
	replace	networkbud_puredummy	=	2	if	country_name	==	"Denmark"	&	year	==	1986
	replace	networkbud_puredummy	=	3	if	country_name	==	"Denmark"	&	year	==	1987
	replace	networkbud_puredummy	=	4	if	country_name	==	"Denmark"	&	year	==	1988
	replace	networkbud_puredummy	=	1	if	country_name	==	"Germany"	&	year	==	1989
	replace	networkbud_puredummy	=	2	if	country_name	==	"Germany"	&	year	==	1990
	replace	networkbud_puredummy	=	3	if	country_name	==	"Germany"	&	year	==	1991
	replace	networkbud_puredummy	=	4	if	country_name	==	"Germany"	&	year	==	1992
	replace	networkbud_puredummy	=	5	if	country_name	==	"Germany"	&	year	==	1993
	replace	networkbud_puredummy	=	6	if	country_name	==	"Germany"	&	year	==	1994
	replace	networkbud_puredummy	=	7	if	country_name	==	"Germany"	&	year	==	1995
	replace	networkbud_puredummy	=	1	if	country_name	==	"Finland"	&	year	==	1996
	replace	networkbud_puredummy	=	2	if	country_name	==	"Finland"	&	year	==	1997
	replace	networkbud_puredummy	=	3	if	country_name	==	"Finland"	&	year	==	1998
	replace	networkbud_puredummy	=	4	if	country_name	==	"Finland"	&	year	==	1999
	replace	networkbud_puredummy	=	1	if	country_name	==	"Germany"	&	year	==	1999
	replace	networkbud_puredummy	=	2	if	country_name	==	"Germany"	&	year	==	2000
	replace	networkbud_puredummy	=	3	if	country_name	==	"Germany"	&	year	==	2001
	replace	networkbud_puredummy	=	4	if	country_name	==	"Germany"	&	year	==	2002
	replace	networkbud_puredummy	=	5	if	country_name	==	"Germany"	&	year	==	2003
	replace	networkbud_puredummy	=	6	if	country_name	==	"Germany"	&	year	==	2004
	replace	networkbud_puredummy	=	1	if	country_name	==	"Cyprus"	&	year	==	2004
	replace	networkbud_puredummy	=	1	if	country_name	==	"Lithunia"	&	year	==	2004
	replace	networkbud_puredummy	=	2	if	country_name	==	"Lithunia"	&	year	==	2005
	replace	networkbud_puredummy	=	3	if	country_name	==	"Lithunia"	&	year	==	2006
	replace	networkbud_puredummy	=	4	if	country_name	==	"Lithunia"	&	year	==	2007

	//Regional commissioner
		
	//Antonia Giolitti ITA 6 January 1977- 6 January 1985			
	//Grigorius Varfis GRE 7 January 1985  -   31 December 1985			
	//Alois Pfeiffer GER 1 January 1986 - 1 August 1987 // Es gibt parallel einen Commissioner fr structural instruments (Grigorius Varfis) bzw. spter fr structural funds (und der Agrarkommissar ist spter auch fr rural development verantwortlich)			
	//Peter Schmidhuber GER 22 September 1987 - 5 January 1989			
	//Bruce Millan UK 6 January 1989  24 January 1995			
	//Monika Wulf-Mathies GER 25 January 1995  17 September 1999 (explizit auch fr Cohesion Fund)			
	//Michel Barnier FRA 17 September 1999  1 April 2004			
	//Jacques Barrot FRA 26 April 2004  21 November 2004			
	//Pter Balzs HUN 1 May 2004 21 November 2004			
	//Danuta Hbner POL 22 November 2004 4 July 2009			
		

	gen natcomreg=0

	replace	natcomreg	=	1	if	country_name	==	"Italy"	&	year	==	1977
	replace	natcomreg	=	1	if	country_name	==	"Italy"	&	year	==	1978
	replace	natcomreg	=	1	if	country_name	==	"Italy"	&	year	==	1979
	replace	natcomreg	=	1	if	country_name	==	"Italy"	&	year	==	1980
	replace	natcomreg	=	1	if	country_name	==	"Italy"	&	year	==	1981
	replace	natcomreg	=	1	if	country_name	==	"Italy"	&	year	==	1982
	replace	natcomreg	=	1	if	country_name	==	"Italy"	&	year	==	1983
	replace	natcomreg	=	1	if	country_name	==	"Italy"	&	year	==	1984
	replace	natcomreg	=	0.0833333	if	country_name	==	"Poland"	&	year	==	2004
	replace	natcomreg	=	1	if	country_name	==	"Poland"	&	year	==	2005
	replace	natcomreg	=	1	if	country_name	==	"Poland"	&	year	==	2006
	replace	natcomreg	=	1	if	country_name	==	"Poland"	&	year	==	2007
	replace	natcomreg	=	1	if	country_name	==	"United Kingdom"	&	year	==	1989
	replace	natcomreg	=	1	if	country_name	==	"United Kingdom"	&	year	==	1990
	replace	natcomreg	=	1	if	country_name	==	"United Kingdom"	&	year	==	1991
	replace	natcomreg	=	1	if	country_name	==	"United Kingdom"	&	year	==	1992
	replace	natcomreg	=	1	if	country_name	==	"United Kingdom"	&	year	==	1993
	replace	natcomreg	=	1	if	country_name	==	"United Kingdom"	&	year	==	1994
	replace	natcomreg	=	0.0833333	if	country_name	==	"United Kingdom"	&	year	==	1995
	replace	natcomreg	=	1	if	country_name	==	"Greece"	&	year	==	1985
	replace	natcomreg	=	1	if	country_name	==	"Germany"	&	year	==	1986
	replace	natcomreg	=	1	if	country_name	==	"Germany"	&	year	==	1987
	replace	natcomreg	=	1	if	country_name	==	"Germany"	&	year	==	1988
	replace	natcomreg	=	0.9166667	if	country_name	==	"Germany"	&	year	==	1995
	replace	natcomreg	=	1	if	country_name	==	"Germany"	&	year	==	1996
	replace	natcomreg	=	1	if	country_name	==	"Germany"	&	year	==	1997
	replace	natcomreg	=	1	if	country_name	==	"Germany"	&	year	==	1998
	replace	natcomreg	=	0.75	if	country_name	==	"Germany"	&	year	==	1999
	replace	natcomreg	=	0.25	if	country_name	==	"France"	&	year	==	1999
	replace	natcomreg	=	1	if	country_name	==	"France"	&	year	==	2000
	replace	natcomreg	=	1	if	country_name	==	"France"	&	year	==	2001
	replace	natcomreg	=	1	if	country_name	==	"France"	&	year	==	2002
	replace	natcomreg	=	1	if	country_name	==	"France"	&	year	==	2003
	replace	natcomreg	=	0.9166667	if	country_name	==	"France"	&	year	==	2004
	replace	natcomreg	=	0.5833333	if	country_name	==	"Hungary"	&	year	==	2004
		

	gen networkreg = 0
		
	replace	networkreg	=	1	if	country_name	==	"Italy"	&	year	==	1977
	replace	networkreg	=	2	if	country_name	==	"Italy"	&	year	==	1978
	replace	networkreg	=	3	if	country_name	==	"Italy"	&	year	==	1979
	replace	networkreg	=	4	if	country_name	==	"Italy"	&	year	==	1980
	replace	networkreg	=	5	if	country_name	==	"Italy"	&	year	==	1981
	replace	networkreg	=	6	if	country_name	==	"Italy"	&	year	==	1982
	replace	networkreg	=	7	if	country_name	==	"Italy"	&	year	==	1983
	replace	networkreg	=	8	if	country_name	==	"Italy"	&	year	==	1984
	replace	networkreg	=	0.0833333	if	country_name	==	"Poland"	&	year	==	2004
	replace	networkreg	=	1.0833333	if	country_name	==	"Poland"	&	year	==	2005
	replace	networkreg	=	2.0833333	if	country_name	==	"Poland"	&	year	==	2006
	replace	networkreg	=	3.0833333	if	country_name	==	"Poland"	&	year	==	2007
	replace	networkreg	=	1	if	country_name	==	"United Kingdom"	&	year	==	1989
	replace	networkreg	=	2	if	country_name	==	"United Kingdom"	&	year	==	1990
	replace	networkreg	=	3	if	country_name	==	"United Kingdom"	&	year	==	1991
	replace	networkreg	=	4	if	country_name	==	"United Kingdom"	&	year	==	1992
	replace	networkreg	=	5	if	country_name	==	"United Kingdom"	&	year	==	1993
	replace	networkreg	=	6	if	country_name	==	"United Kingdom"	&	year	==	1994
	replace	networkreg	=	7	if	country_name	==	"United Kingdom"	&	year	==	1995
	replace	networkreg	=	1	if	country_name	==	"Greece"	&	year	==	1985
	replace	networkreg	=	0.416666667	if	country_name	==	"Germany"	&	year	==	1986
	replace	networkreg	=	1.416667	if	country_name	==	"Germany"	&	year	==	1987
	replace	networkreg	=	2.416667	if	country_name	==	"Germany"	&	year	==	1988
	replace	networkreg	=	0.916666667	if	country_name	==	"Germany"	&	year	==	1995
	replace	networkreg	=	1.916666667	if	country_name	==	"Germany"	&	year	==	1996
	replace	networkreg	=	2.916666667	if	country_name	==	"Germany"	&	year	==	1997
	replace	networkreg	=	3.916666667	if	country_name	==	"Germany"	&	year	==	1998
	replace	networkreg	=	4.666666667	if	country_name	==	"Germany"	&	year	==	1999
	replace	networkreg	=	0.25	if	country_name	==	"France"	&	year	==	1999
	replace	networkreg	=	1.25	if	country_name	==	"France"	&	year	==	2000
	replace	networkreg	=	2.25	if	country_name	==	"France"	&	year	==	2001
	replace	networkreg	=	3.25	if	country_name	==	"France"	&	year	==	2002
	replace	networkreg	=	4.25	if	country_name	==	"France"	&	year	==	2003
	replace	networkreg	=	0.5833333	if	country_name	==	"France"	&	year	==	2004
	replace	networkreg	=	0.583333333	if	country_name	==	"Hungary"	&	year	==	2004
			
			
	gen natcomreg_puredummy =0
			
	replace	natcomreg_puredummy	=	1	if	country_name	==	"Italy"	&	year	==	1977
	replace	natcomreg_puredummy	=	1	if	country_name	==	"Italy"	&	year	==	1978
	replace	natcomreg_puredummy	=	1	if	country_name	==	"Italy"	&	year	==	1979
	replace	natcomreg_puredummy	=	1	if	country_name	==	"Italy"	&	year	==	1980
	replace	natcomreg_puredummy	=	1	if	country_name	==	"Italy"	&	year	==	1981
	replace	natcomreg_puredummy	=	1	if	country_name	==	"Italy"	&	year	==	1982
	replace	natcomreg_puredummy	=	1	if	country_name	==	"Italy"	&	year	==	1983
	replace	natcomreg_puredummy	=	1	if	country_name	==	"Italy"	&	year	==	1984
	replace	natcomreg_puredummy	=	1	if	country_name	==	"Poland"	&	year	==	2004
	replace	natcomreg_puredummy	=	1	if	country_name	==	"Poland"	&	year	==	2005
	replace	natcomreg_puredummy	=	1	if	country_name	==	"Poland"	&	year	==	2006
	replace	natcomreg_puredummy	=	1	if	country_name	==	"Poland"	&	year	==	2007
	replace	natcomreg_puredummy	=	1	if	country_name	==	"United Kingdom"	&	year	==	1989
	replace	natcomreg_puredummy	=	1	if	country_name	==	"United Kingdom"	&	year	==	1990
	replace	natcomreg_puredummy	=	1	if	country_name	==	"United Kingdom"	&	year	==	1991
	replace	natcomreg_puredummy	=	1	if	country_name	==	"United Kingdom"	&	year	==	1992
	replace	natcomreg_puredummy	=	1	if	country_name	==	"United Kingdom"	&	year	==	1993
	replace	natcomreg_puredummy	=	1	if	country_name	==	"United Kingdom"	&	year	==	1994
	replace	natcomreg_puredummy	=	1	if	country_name	==	"United Kingdom"	&	year	==	1995
	replace	natcomreg_puredummy	=	1	if	country_name	==	"Greece"	&	year	==	1985
	replace	natcomreg_puredummy	=	1	if	country_name	==	"Germany"	&	year	==	1986
	replace	natcomreg_puredummy	=	1	if	country_name	==	"Germany"	&	year	==	1987
	replace	natcomreg_puredummy	=	1	if	country_name	==	"Germany"	&	year	==	1988
	replace	natcomreg_puredummy	=	1	if	country_name	==	"Germany"	&	year	==	1995
	replace	natcomreg_puredummy	=	1	if	country_name	==	"Germany"	&	year	==	1996
	replace	natcomreg_puredummy	=	1	if	country_name	==	"Germany"	&	year	==	1997
	replace	natcomreg_puredummy	=	1	if	country_name	==	"Germany"	&	year	==	1998
	replace	natcomreg_puredummy	=	1	if	country_name	==	"Germany"	&	year	==	1999
	replace	natcomreg_puredummy	=	1	if	country_name	==	"France"	&	year	==	1999
	replace	natcomreg_puredummy	=	1	if	country_name	==	"France"	&	year	==	2000
	replace	natcomreg_puredummy	=	1	if	country_name	==	"France"	&	year	==	2001
	replace	natcomreg_puredummy	=	1	if	country_name	==	"France"	&	year	==	2002
	replace	natcomreg_puredummy	=	1	if	country_name	==	"France"	&	year	==	2003
	replace	natcomreg_puredummy	=	1	if	country_name	==	"France"	&	year	==	2004
	replace	natcomreg_puredummy	=	1	if	country_name	==	"Hungary"	&	year	==	2004
												
	gen networkreg_puredummy = 0
												
	replace	networkreg_puredummy	=	1	if	country_name	==	"Italy"	&	year	==	1977
	replace	networkreg_puredummy	=	2	if	country_name	==	"Italy"	&	year	==	1978
	replace	networkreg_puredummy	=	3	if	country_name	==	"Italy"	&	year	==	1979
	replace	networkreg_puredummy	=	4	if	country_name	==	"Italy"	&	year	==	1980
	replace	networkreg_puredummy	=	5	if	country_name	==	"Italy"	&	year	==	1981
	replace	networkreg_puredummy	=	6	if	country_name	==	"Italy"	&	year	==	1982
	replace	networkreg_puredummy	=	7	if	country_name	==	"Italy"	&	year	==	1983
	replace	networkreg_puredummy	=	8	if	country_name	==	"Italy"	&	year	==	1984
	replace	networkreg_puredummy	=	1	if	country_name	==	"Poland"	&	year	==	2004
	replace	networkreg_puredummy	=	2	if	country_name	==	"Poland"	&	year	==	2005
	replace	networkreg_puredummy	=	3	if	country_name	==	"Poland"	&	year	==	2006
	replace	networkreg_puredummy	=	4	if	country_name	==	"Poland"	&	year	==	2007
	replace	networkreg_puredummy	=	1	if	country_name	==	"United Kingdom"	&	year	==	1989
	replace	networkreg_puredummy	=	2	if	country_name	==	"United Kingdom"	&	year	==	1990
	replace	networkreg_puredummy	=	3	if	country_name	==	"United Kingdom"	&	year	==	1991
	replace	networkreg_puredummy	=	4	if	country_name	==	"United Kingdom"	&	year	==	1992
	replace	networkreg_puredummy	=	5	if	country_name	==	"United Kingdom"	&	year	==	1993
	replace	networkreg_puredummy	=	6	if	country_name	==	"United Kingdom"	&	year	==	1994
	replace	networkreg_puredummy	=	7	if	country_name	==	"United Kingdom"	&	year	==	1995
	replace	networkreg_puredummy	=	1	if	country_name	==	"Greece"	&	year	==	1985
	replace	networkreg_puredummy	=	1	if	country_name	==	"Germany"	&	year	==	1986
	replace	networkreg_puredummy	=	1	if	country_name	==	"Germany"	&	year	==	1987
	replace	networkreg_puredummy	=	2	if	country_name	==	"Germany"	&	year	==	1988
	replace	networkreg_puredummy	=	3	if	country_name	==	"Germany"	&	year	==	1995
	replace	networkreg_puredummy	=	4	if	country_name	==	"Germany"	&	year	==	1996
	replace	networkreg_puredummy	=	5	if	country_name	==	"Germany"	&	year	==	1997
	replace	networkreg_puredummy	=	6	if	country_name	==	"Germany"	&	year	==	1998
	replace	networkreg_puredummy	=	7	if	country_name	==	"Germany"	&	year	==	1999
	replace	networkreg_puredummy	=	1	if	country_name	==	"France"	&	year	==	1999
	replace	networkreg_puredummy	=	2	if	country_name	==	"France"	&	year	==	2000
	replace	networkreg_puredummy	=	3	if	country_name	==	"France"	&	year	==	2001
	replace	networkreg_puredummy	=	4	if	country_name	==	"France"	&	year	==	2002
	replace	networkreg_puredummy	=	5	if	country_name	==	"France"	&	year	==	2003
	replace	networkreg_puredummy	=	1	if	country_name	==	"France"	&	year	==	2004
	replace	networkreg_puredummy	=	1	if	country_name	==	"Hungary"	&	year	==	2004



	*Interaction effect
	gen natcom_preelect=natcom*preelection
	* Generates interaction term


	* Generate Year Dummies for checking Time-FE, one is reference category:
	forvalues i = 2(1)31{
	gen y`i'=0
	}

	forvalues i = 2(1)31{
	replace y`i'=1 if year==1976 +`i'
	}


	* Labeling of variables

	label variable natcom "Commissioner" 
	label variable natcombud "Commissioner (B)"
	label variable natcomreg "Commissioner (R)"
	label variable natcom_preelect "EUCA_Preelection Year" 
	label variable ccap_pct "Agricultural Fund Share"
	label variable natcom_puredummy "Commissioner (Dummy)"
	label variable year "Year"
	label variable network "Time in Office"
	label variable networkreg "Commissioner's time in office"
	label variable networkbud "Commissioner's time in office"
	label variable ttrend1 "Specific Timetrend 1"

	forvalues i = 2(1)22{
	label variable ttrend`i' "Specific Timetrend `i'"
	}

	forvalues i = 25(1)27{
	label variable ttrend`i' "Specific Timetrend `i'"
	}

	*Further labels

	label variable y2 "Dummy for 1978"
	label variable y3 "Dummy for 1979"
	label variable y4 "Dummy for 1980"
	label variable y5 "Dummy for 1981"
	label variable y6 "Dummy for 1982"
	label variable y7 "Dummy for 1983"
	label variable y8 "Dummy for 1984"
	label variable y9 "Dummy for 1985"
	label variable y10 "Dummy for 1986"
	label variable y11 "Dummy for 1987"
	label variable y12 "Dummy for 1988"
	label variable y13 "Dummy for 1989"
	label variable y14 "Dummy for 1990"
	label variable y15 "Dummy for 1991"
	label variable y16 "Dummy for 1992"
	label variable y17 "Dummy for 1993"
	label variable y18 "Dummy for 1994"
	label variable y19 "Dummy for 1995"
	label variable y20 "Dummy for 1996"
	label variable y21 "Dummy for 1997"
	label variable y22 "Dummy for 1998"
	label variable y23 "Dummy for 1999"
	label variable y24 "Dummy for 2000"
	label variable y25 "Dummy for 2001"
	label variable y26 "Dummy for 2002"
	label variable y27 "Dummy for 2003"
	label variable y28 "Dummy for 2004"
	label variable y29 "Dummy for 2005"
	label variable y30 "Dummy for 2006"
	label variable y31 "Dummy for 2007"

	*Both countries have no obervations with data in our sample period
	drop  if country_name=="Bulgaria"
	drop  if country_name=="Romania"
	*no data in obs-period *25 countries in the sample

	*Correct mistake in dataset from C. Schneider:
	replace cap = . if country_name=="Denmark" & year==2006
	replace ccap = . if country_name=="Denmark" & year==2006
	replace ccap_pct = . if country_name=="Denmark" & year==2006
	replace ctotreceived = . if country_name=="Denmark" & year==2006
	replace ctot_pct = . if country_name=="Denmark" & year==2006

	replace cap = 1164.8 if country_name=="Denmark" & year==2006
	replace ccap = 1164.8 if country_name=="Denmark" & year==2006
	replace ccap_pct = 1.047305894 if country_name=="Denmark" & year==2006
	replace ctotreceived = 1455.5 if country_name=="Denmark" & year==2006
	replace ctot_pct = 1.308682802 if country_name=="Denmark" & year==2006


	*********Lags and Leads

	 gen L1natcom=0
		label  var L1natcom "Commissioner (t+1)"
	  replace L1natcom=1 if l.natcom!=0 & natcom==0 &l.natcom!=.
		gen L2natcom=0
		label  var L2natcom "Commissioner  (t+2)"
		replace L2natcom=1 if l2.natcom!=0 & l.natcom==0 & natcom==0 &l2.natcom!=.
			gen L3natcom=0
		label  var L3natcom "Commissioner  (t+3)"
		replace L3natcom=1 if l3.natcom!=0 & l2.natcom==0 & l.natcom==0 & natcom==0 &l3.natcom!=.
		 gen L4natcom=0
	label  var L4natcom "Commissioner (t+4)"	 
		replace L4natcom=1 if l4.natcom!=0  & l3.natcom==0   & l2.natcom==0 & l.natcom==0 & natcom==0 &l4.natcom!=.
		gen F1natcom=0
	label  var F1natcom "Commissioner  (t-1)"	
	  replace F1natcom=1 if f1.natcom!=0 & natcom==0 &f1.natcom!=.
		gen F2natcom=0
	label  var F2natcom "Commissioner  (t-2)"	
		replace F2natcom=1 if f2.natcom!=0 & f1.natcom==0 & natcom==0 &f2.natcom!=.


	*Manual coding Leads and Lags: Countries whicht had the Commissioner before/after the sample
	*Denmark had the Commissioner from JAN 1977. Before, NL had the Commissioner (see: https://www.munzinger.de/search/document?index=mol-00&id=00000013414&type=text/html&query.key=QIAoxy9Y&template=/publikationen/personen/document.jsp&preview==)
	replace L1natcom = 1 if countryname=="Netherlands" & year==1977
	replace L2natcom = 1 if countryname=="Netherlands" & year==1978
	replace L3natcom = 1 if countryname=="Netherlands" & year==1979
	replace L4natcom = 1 if countryname=="Netherlands" & year==1980
	*Denmark had the Commissioner until FEB 2009; No additional lead variables have to be inserted.	
		


	order country_name country_id year ccap_pct natcom   natcom_puredummy natcombud natcomreg preelection  election_year  employagri_ln  gdppercap_eu100 unemploymentrate  sscouncil_pct  eusupport  newmember 


******************************************************************************
********************************************************************************

	* New dependent variable (agricultural fund 100%)
	bysort year: egen agricfundtotal=total(ccap_pct)
	gen agricfundtotal_pct=agricfundtotal/100
	gen agricfund_pct=ccap_pct/agricfundtotal_pct

	*to check the new variable sums up to 100:
	bysort year: egen agricfund_pct_total=total(agricfund_pct)


	*Generate log-Variables of fund receipts in %
	gen ln_agricfund_pct = log(agricfund_pct)
	gen ln_ccap_pct = log(ccap_pct)


	*Generate log-Variables of fund receipts
	gen ln_ccap=log(ccap)

	drop _merge
	sort country_name year	
	saveold "data processed\public_temp1.dta",replace 

	
	
	***********************************************************************************
	*****************************Add other variables and fill up**********************
	use "data processed\public_temp1.dta",clear

	merge 1:1 country_name year using "data processed\worldindicators.dta"	, keep(1 3) nogen
		
	merge 1:1 country_name year using "data processed\Eurostat.dta", keep(1 3) nogen
	bys country_id: carryforward code,replace //Some missing in code, needed to merge
	gsort +country_id -year
	by country_id: carryforward code,replace //Some missing in code, needed to merge
	bys country_id: carryforward code,replace //Some missing in code, needed to merge
	drop if code==""
	merge 1:1  code year using "data processed\Eucouncil.dta", keep(1 3) nogen keepusing(Eucouncil)
	bys country_id: carryforward code,replace //Some missing in code, needed to merge
	gsort +country_id -year
	by country_id: carryforward code,replace //Some missing in code, needed to merge
		
	sort country_id year
	replace Eucouncil=0 if Eucouncil==.
	label var Eucouncil "Country has presidency in EU council if 1"
	
	merge 1:1 code year using 	"data processed\Eupres.dta" , nogen keep(1 3) keepusing(Eupres)
	replace Eupres=0 if Eupres==.

	
	*Agricultural value added, replace values for Malta with WDI 2013 values by hand, seems to be problem with wbopendata
replace nv_agr_totl_zs=3.4667847410833 if year==1990&code=="MLT"
replace nv_agr_totl_zs=3.29999186283473 if year==1991&code=="MLT"
replace nv_agr_totl_zs=3.04986953847844 if year==1992&code=="MLT"
replace nv_agr_totl_zs=3.00819290861638 if year==1993&code=="MLT"
replace nv_agr_totl_zs=2.80207632456757 if year==1994&code=="MLT"
replace nv_agr_totl_zs=2.86431587355928 if year==1995&code=="MLT"
replace nv_agr_totl_zs=2.94096472282217 if year==1996&code=="MLT"
replace nv_agr_totl_zs=2.82491686379375 if year==1997&code=="MLT"
replace nv_agr_totl_zs=2.86916848734096 if year==1998&code=="MLT"
replace nv_agr_totl_zs=2.68481286730591 if year==1999&code=="MLT"
replace nv_agr_totl_zs=2.34609929078014 if year==2000&code=="MLT"
replace nv_agr_totl_zs=2.76458854269098 if year==2001&code=="MLT"
replace nv_agr_totl_zs=2.77889218754179 if year==2002&code=="MLT"
replace nv_agr_totl_zs=2.88826368634334 if year==2003&code=="MLT"
replace nv_agr_totl_zs=2.72588055130168 if year==2004&code=="MLT"
replace nv_agr_totl_zs=2.63442800433057 if year==2005&code=="MLT"
replace nv_agr_totl_zs=2.67728427267111 if year==2006&code=="MLT"

	*Gross Value Added Variable
	gen gva_agric_pct = 0
	replace gva_agric_pct = agriculturegva_pct 
	replace gva_agric_pct = nv_agr_totl_zs if agriculturegva_pct ==.
	label	variable	gva_agric_pct	"GVA Agriculture(%GDP)" // based on Variable by C.Schneider. Uses nv_agr_totl_zs for missings.	
	*Data for Malta still missing.

	**Fill up some missings in original employment in agriculture variable with data from World Bank
	replace employagri_ln=employagri_LOG10 if employagri_ln==.
	
	*Eurostat Data for UK Missing 1983	(http://sdw.ecb.europa.eu/quickview.do?SERIES_KEY=132.STS.M.GB.S.UNEH.RTT000.4.000)
	replace unemploymentrate=10.84333333 if country_name=="United Kingdom" & year==1983	
	
	order country_name country_id year ccap_pct natcom   natcom_puredummy natcombud natcomreg preelection  election_year  employagri_ln gdppercap_eu100 unemploymentrate  sscouncil_pct  eusupport  newmember 

	tab country_id,gen(Dcountry)
	tab year,gen(Dyear)

	******************************Count variabel for Event study graph**************************************
	***********************************************************************************
	***********************************************************************************

	xtset country_id year
	cap noisily bys country_id:egen treat=sum(natcom)
	cap noisily drop eventtime
	gen eventtime=.
	replace eventtime=0 if natcom!=0 & natcom!=. & l.natcom==0 & l.natcom!=.
	replace eventtime=0 if country_id==2 & year==1977 //Denmark
		
	by country_id :replace eventtime=eventtime[_n-1]+1 if eventtime==. &treat>0
	by country_id :replace eventtime=eventtime[_n+1]-1 if eventtime==. &treat>0
	by country_id :replace eventtime=eventtime[_n+1]-1 if eventtime==. &treat>0
	by country_id :replace eventtime=eventtime[_n+1]-1 if eventtime==. &treat>0
	by country_id :replace eventtime=eventtime[_n+1]-1 if eventtime==. &treat>0
	by country_id :replace eventtime=eventtime[_n+1]-1 if eventtime==. &treat>0
	
		replace eventtime=-1 if country_id==2 & year==2003 //Denmark
	replace eventtime=-2 if country_id==2 & year==2002 //Denmark
	replace eventtime=-3 if country_id==2 & year==2001 //Denmark
	replace eventtime=-4 if country_id==2 & year==2000 //Denmark
		replace eventtime=-5 if country_id==2 & year==1999 //Denmark
	
	*Correct for start in 1979
	replace eventtime=eventtime-2 if country_id==2 & year<1999

	
	
	
		

	******************************Count variable for Event study graph 2**************************************
	***********************************************************************************
	***********************************************************************************

	xtset country_id year

	cap noisily drop eventtime2
	gen eventtime2=.
	replace eventtime2=0 if natcom!=0 & natcom!=. & f.natcom==0 & f.natcom!=.
	*replace eventtime2=0 if country_id==2 & year==1977 //Denmark
		
	by country_id :replace eventtime2=eventtime2[_n-1]+1 if eventtime2==. &treat>0
	*! 8 pre event
	by country_id :replace eventtime2=eventtime2[_n+1]-1 if eventtime2==. &treat>0
	by country_id :replace eventtime2=eventtime2[_n+1]-1 if eventtime2==. &treat>0
	by country_id :replace eventtime2=eventtime2[_n+1]-1 if eventtime2==. &treat>0
	by country_id :replace eventtime2=eventtime2[_n+1]-1 if eventtime2==. &treat>0
	by country_id :replace eventtime2=eventtime2[_n+1]-1 if eventtime2==. &treat>0
	by country_id :replace eventtime2=eventtime2[_n+1]-1 if eventtime2==. &treat>0
	by country_id :replace eventtime2=eventtime2[_n+1]-1 if eventtime2==. &treat>0
	by country_id :replace eventtime2=eventtime2[_n+1]-1 if eventtime2==. &treat>0
					
	
		replace eventtime2=-2 if country_id==2 & year==2007 //Denmark
	replace eventtime2=-3 if country_id==2 & year==2006 //Denmark
	replace eventtime2=-4 if country_id==2 & year==2005 //Denmark
	replace eventtime2=-5 if country_id==2 & year==2004 //Denmark
	replace eventtime2=-6 if country_id==2 & year==2003 //Denmark
	replace eventtime2=-7 if country_id==2 & year==2002 //Denmark
	replace eventtime2=-8 if country_id==2 & year==2001 //Denmark
	replace eventtime2=-9 if country_id==2 & year==2000 //Denmark
	*Correct for start in 1979
	*replace eventtime2=eventtime2-2 if country_id==2 & year<2000 


	
	
	
	
	
	
	
	 *Final Labeling
 label variable 	ccap_pct	 	"Agricultural Fund Share"
 label variable 	ln_ccap_pct	 	"Agricultural Fund Share (ln)"
label variable 	agricfund_pct	 	"Agricultural Fund Share (100)"
label variable 	ctot_pct	 	"Overall Funds Share"
label variable 	natcom	 	"Commissioner"
label variable 	natcom_puredummy	 	"Commissioner (Binary)"
label variable 	natcombud	 	"Commissioner (B)"
label variable 	natcomreg	 "Commissioner (R)"
label variable 	network	 	"Time in Office"
label variable 	preelection	 	"Pre-election Year"
label variable 	election_year	 	"Election Year"
label variable gdppercap_eu100 "Per Capita GDP (EU=100)"
label variable 	employagri_ln	 	"Employment Agriculture (ln)"
label variable 	gva_agric_pct	 	"GVA Agriculture"
label variable 	unemploymentrate	 	"Unemployment Rate"
label variable 	newmember	 	"New Member State"
label variable 	sscouncil_pct	 	"Voting Power Council"
label variable 	eusupport	 	"Domestic EU Support"
label variable 	Eucouncil	 	"Council Presidency"
label variable 	Eupres	 	"EC President"
	
	
	*for Latex use
	 label variable 	ccap_pct	 	"\textit{Agricultural Fund Share}"
 label variable 	ln_ccap_pct	 	"\textit{Agricultural Fund Share (ln)}"
label variable 	agricfund_pct	 	"\textit{Agricultural Fund Share (100)}"
label variable 	ctot_pct	 	"\textit{Overall Funds Share}"
label variable 	natcom	 	"\textit{Commissioner}"
label variable 	natcom_puredummy	 	"\textit{Commissioner (Binary)}"
label variable 	natcombud	 	"\textit{Commissioner (B)}"
label variable 	natcomreg	 "\textit{Commissioner (R)}"
label variable 	network	 	"\textit{Time in Office}"
label variable 	preelection	 	"\textit{Pre-election Year}"
label variable 	election_year	 	"\textit{Election Year}"
label variable gdppercap_eu100 "\textit{Per Capita GDP (EU=100)}"
label variable 	employagri_ln	 	"\textit{Employment Agriculture (ln)}"
label variable 	gva_agric_pct	 	"\textit{GVA Agriculture}"
label variable 	unemploymentrate	 	"\textit{Unemployment Rate}"
label variable 	newmember	 	"\textit{New Member State}"
label variable 	sscouncil_pct	 	"\textit{Voting Power Council}"
label variable 	eusupport	 	"\textit{Domestic EU Support}"
label variable 	Eucouncil	 	"\textit{Council Presidency}"
label variable 	Eupres	 	"\textit{EC President}"
label  var L1natcom "\textit{Commissioner (t+1)}"	
label  var L2natcom "\textit{Commissioner (t+2)}"	
label  var L3natcom "\textit{Commissioner (t+3)}"	
label  var L4natcom "\textit{Commissioner (t+4)}"	
label  var F1natcom "\textit{Commissioner (t-1)}"	
label  var F2natcom "\textit{Commissioner (t-2)}"	
label  var year "\textit{Year}"	

cap noisily save "data processed\public_eupower2.dta", replace  //If Stata version is version 12					
cap noisily saveold "data processed\public_eupower2.dta", replace version(12)  //For all other versions


	


	exit 











	************************************THE*END************************************  


